#ifndef RULESWINDOW_H
#define RULESWINDOW_H

#include <QMainWindow>
#include "controls/dialogwindow.h"

namespace Ui {
    class RulesWindow;
}

class RulesWindow : public DialogWindow
{
    Q_OBJECT

public:
    explicit RulesWindow(QWidget *parent = 0, QString bookDirectory="");
    ~RulesWindow();

    void ScrollToAnchor(QString anchor);
    void show();

private:
    Ui::RulesWindow *ui;

    QString m_BookDirectory;
};

#endif // RULESWINDOW_H
